%bcond_without dotests

Name:           wget2
Version:	2.1.0
Release:	2
Summary:        An advanced file and recursive website downloader
License:        GPL-3.0-or-later AND LGPL-3.0-or-later AND GFDL-1.3-or-later
URL:            https://gitlab.com/gnuwget/wget2
Source0:	https://ftp.gnu.org/gnu/wget/wget2-%{version}.tar.gz
Source1:	https://ftp.gnu.org/gnu/wget/wget2-%{version}.tar.gz.sig
Patch0:		wget2-2.1.0-max_align.patch
Patch1:		wget2-2.1.0-getnameinfo.patch
Patch2:		wget2-2.1.0-dns.patch

BuildRequires:	gpgme-devel >= 1.13.1
BuildRequires:	gettext-devel >= 0.21
BuildRequires:	libnghttp2-devel >= 1.62.1
BuildRequires:	pcre2-devel >= 10.40
BuildRequires:	libzstd-devel >= 1.5.2
Requires:	gpgme >= 1.13.1
Requires:	libiconv >= 1.17
Requires:	gettext >= 0.21
Requires:	libnghttp2 >= 1.62.1
Requires:	pcre2 >= 10.40
Requires:	libzstd >= 1.5.2
Requires:       %{name}-libs = %{version}-%{release}

%description

GNU Wget2 is the successor of GNU Wget, a file and recursive website
downloader.

Designed and written from scratch it wraps around libwget, that provides the
basic functions needed by a web client.

Wget2 works multi-threaded and uses many features to allow fast operation.
In many cases Wget2 downloads much faster than Wget1.x due to HTTP2, HTTP
compression, parallel connections and use of If-Modified-Since HTTP header.

%package libs
Summary:        Runtime libraries for GNU Wget2
# There's some gnulib in there :)
Provides:       bundled(gnulib)

Requires:	gpgme >= 1.13.1
Requires:	libiconv >= 1.17
Requires:	gettext >= 0.21
Requires:	libnghttp2 >= 1.62.1
Requires:	pcre2 >= 10.40
Requires:	libzstd >= 1.5.2
Requires:	zlib >= 1.2.13
%if %{toolchain} == "gcc"
Requires:	libgcc >= 10.3.0
%endif

%description libs
This package contains the libraries for applications to use
Wget2 functionality.

%package devel
Summary:        Libraries and header files needed for using wget2 libraries
Requires:       %{name}-libs = %{version}-%{release}

%description devel
Development libraries and headers needed for building applications to
use functionality from GNU Wget2.

%prep
%setup
%patch0 -p1
%patch1 -p1
%patch2 -p1

rm -rf   /tmp/%{name}-%{version}-32bit
cp -pr . /tmp/%{name}-%{version}-32bit
rm -fr *
mv       /tmp/%{name}-%{version}-32bit 32bit
cp -pr 32bit 64bit

cd 64bit


%build

# build on 64bit mode
cd 64bit
export OBJECT_MODE=64
export CC="%{__cc__} -O2 -maix64 -pthread"
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib"
./configure --prefix=%{_prefix} --libdir=%{_libdir}64 --disable-static --with-ssl=openssl
gmake V=1

# build on 32bit mode
cd ../32bit
export OBJECT_MODE=32
export CC="%{__cc__} -O2 -maix32 -D_LARGE_FILES -pthread"
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure --prefix=%{_prefix} --libdir=%{_libdir}  --disable-static --with-ssl=openssl
gmake V=1


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

# install on 32bit mode
cd 32bit
export OBJECT_MODE=32
gmake install DESTDIR="${RPM_BUILD_ROOT}"

# install on 64bit mode
cd ../64bit
export OBJECT_MODE=64
gmake install DESTDIR="${RPM_BUILD_ROOT}"

#Archive 64bit shared object
(
cd ${RPM_BUILD_ROOT}%{_libdir}
ar -X64 -q libwget.a %{_builddir}/%{name}-%{version}/64bit/libwget/.libs/libwget.so.2
)

# tarball includes a pre-built manpage
install -D -m0644 -t %{buildroot}%{_mandir}/man1/ docs/man/man1/wget2.1

%check
%if %{with dotests}
cd 64bit
export OBJECT_MODE=64
gmake -k check || true

cd ../32bit
export OBJECT_MODE=32
gmake -k check || true
%endif


%files
%defattr(-,root,system,-)
%license 32bit/COPYING*
%doc 32bit/README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*

%files libs
%defattr(-,root,system,-)
%license 32bit/COPYING*
%{_libdir}/libwget.a

%files devel
%defattr(-,root,system,-)
%{_includedir}/wget.h
%{_includedir}/wgetver.h
%{_libdir}/pkgconfig/libwget.pc
#Requires doxygen
#%{_mandir}/man3/libwget*.3*

%changelog
* Thu Feb 06 2025 Reshma V Kumar <reskumar@in.ibm.com> - 2.1.0-2 
- Build with openssl 3.0.15

* Tue Nov 19 2024 Reshma V Kumar <reskumar@in.ibm.com> - 2.1.0-1
- Initial port for AIX Toolbox
